<?php
add_theme_support( 'wp-block-styles' );
add_theme_support( 'align-wide' );


function prk_check_gutenberg() {
    if(function_exists( 'register_block_type' )) {
        if (has_blocks()) {
            return true;
        }
    }
    //default
    return false;
}


function prk_tweak_blocks() {
    //Load theme scripts
    wp_enqueue_script(
        'prk_tweak_blocks',
        get_theme_file_uri().( '/js/gutenberg-min.js'),
        array( 'wp-blocks' ),
        PULSE_VERSION
    );

    //LOAD THEME STYLES
    wp_enqueue_style( 'pulse-gutenberg', get_theme_file_uri( '/css/admin-gutenberg.css' ), false, PULSE_VERSION, 'all' );

    //Add styles related with the theme options
    $gut_options=pulse_options();

    $css_build="";

    //FONTS
    $css_build.="html .editor-styles-wrapper,html .editor-styles-wrapper p {font-size:".$gut_options['font_size']."px;}";

    //Body Font
    if (!isset($gut_options['body_font']['css'])) {
        $gut_options['body_font']=array(
            'value' => 'PT+Sans:400,700,400italic,700italic',
            'css' => "'PT Sans', sans-serif",
            'hosted'=> 'google'
        );
    }
    $css_build.="html .editor-styles-wrapper {font-family:".$gut_options['body_font']['css'].";}";

    //Header Font
    if (!isset($gut_options['header_font']['css'])) {
        $gut_options['header_font']=array(
            'value' => 'Open+Sans:300italic,400italic,400,300,700,600,800',
            'css' => "Open Sans",
            'hosted'=> 'google'
        );
    }
    $css_build.="html .editor-post-title__block .editor-post-title__input {font-family:".$gut_options['header_font']['css'].";}";

    //Custom Font
    /*if (!isset($gut_options['custom_font']['css'])) {
        $gut_options['custom_font']=array(
            'value' => 'Libre+Baskerville:400,400italic',
            'css' => "'Libre Baskerville', serif;",
            'hosted'=> 'google'
        );
    }*/


    //TITLE ALIGN
    switch ($gut_options['headings_align']) {
        case 'verve_left_align':
            $css_build.="html .editor-post-title__block .editor-post-title__input {text-align:left;}";
            break;
        case 'verve_right_align':
            $css_build.="html .editor-post-title__block .editor-post-title__input {text-align:right;}";
            break;
        default:
            $css_build.="html .editor-post-title__block .editor-post-title__input {text-align:center;}";
    }

    //COLORS
    $css_build.="html .editor-styles-wrapper,.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce code,.wp-block-freeform.block-library-rich-text__tinymce pre {color:".$gut_options['inactive_color'].";}";
    $css_build.="html .editor-post-title__block .editor-post-title__input {color:".$gut_options['bd_headings_color'].";}";

    //Lines
    $css_build.=".editor-styles-wrapper .mce-item-table {border-top: 1px solid ".$gut_options['lines_color'].";}";
    $css_build.=".editor-styles-wrapper .mce-item-table td,.editor-styles-wrapper .mce-item-table th {border-right: 1px solid ".$gut_options['lines_color'].";}";
    $css_build.=".editor-styles-wrapper .mce-item-table td,.editor-styles-wrapper .mce-item-table th {border-bottom: 1px solid ".$gut_options['lines_color'].";}";
    $css_build.=".editor-styles-wrapper .mce-item-table {border-left: 1px solid ".$gut_options['lines_color'].";}";

    $css_build .= "html .wp-block {max-width: ".$gut_options['custom_width_blog']."px;}";
    $css_build .= "html .post-type-page .wp-block {max-width: ".$gut_options['custom_width']."px;}";

    //OUTPUT THE CUSTOM STYLES WE JUST BUILT
    wp_add_inline_style('pulse-gutenberg',$css_build);

    //FONTS
    $gut_font_families=array();
    //HEADER FONT
    if ($gut_options['header_font']['hosted']=='google') {
        $gut_font_families[]=str_replace('+',' ',$gut_options['header_font']['value']);
    }
    if ($gut_options['header_font']['hosted']=='theme') {
        wp_enqueue_style( 'prk_header_font', get_template_directory_uri() . '/inc/fonts/'.$gut_options['header_font']['value'].'/stylesheet.css',false,PULSE_VERSION);
    }
    if ($gut_options['header_font']['hosted']=='plugin') {
        wp_enqueue_style( 'prk_header_font', $gut_options['header_font']['value'],false,PULSE_VERSION);
    }
    //BODY FONT
    if ($gut_options['body_font']['hosted']=='google') {
        $gut_font_families[]=str_replace('+',' ',$gut_options['body_font']['value']);
    }
    if ($gut_options['body_font']['hosted']=='theme') {
        wp_enqueue_style( 'prk_body_font', get_template_directory_uri() . '/inc/fonts/'.$gut_options['body_font']['value'].'/stylesheet.css',false,PULSE_VERSION);
    }
    if ($gut_options['body_font']['hosted']=='plugin') {
        wp_enqueue_style( 'prk_body_font', $gut_options['body_font']['value'],false,PULSE_VERSION);
    }
    //EXTRA FONT
    $prk_select_font_options=pulse_fonts();
    if ($gut_options['custom_font']!="") {
        foreach ( $prk_select_font_options as $option_custom )
        {
            if ($gut_options['custom_font'] == $option_custom['value'])
            {
                $gut_options['custom_font']=$option_custom;
                break;
            }
        }
        if ($gut_options['custom_font']['hosted']=='google') {
            $gut_font_families[]=str_replace('+',' ',$gut_options['custom_font']['value']);
        }
        if ($gut_options['custom_font']['hosted']=='theme') {
            wp_enqueue_style( 'prk_custom_font', get_template_directory_uri() . '/inc/fonts/'.$gut_options['custom_font']['value'].'/stylesheet.css',false,PULSE_VERSION);
        }
        if ($gut_options['custom_font']['hosted']=='plugin') {
            wp_enqueue_style( 'prk_custom_font', $gut_options['custom_font']['value'],false,PULSE_VERSION);
        }
    }
    if (!empty($gut_font_families)) {
        $query_args=array(
            'family' => urlencode(implode('|', $gut_font_families )),
            'subset' => urlencode('latin,latin-ext'),
        );
        $fonts_url=add_query_arg($query_args,'https://fonts.googleapis.com/css');
        $fonts_url=esc_url_raw($fonts_url);
        wp_enqueue_style('gut_google_fonts', $fonts_url, array(), null );
    }

}
add_action( 'enqueue_block_editor_assets', 'prk_tweak_blocks' );
